@@ -187,11 +187,19 @@ class Controller(WSGIController):
 
         for k, v in filters.items():
             v = self.convert_param(k, v)
-            filter_method = getattr(self.entity, 'filter_by_%s' % k, None)
+            filter_method = getattr(self.entity, '%s_filter' % k, None)
             if filter_method is not None:
-                q = filter_method(q, v)
+                # Prefer a method that returns something that can be passed
+                # into `Query.filter()`.
+                q = q.filter(filter_method(v))
             else:
-                q = q.filter_by(**{k: v})
+                # Next, try a method that takes the `Query` as its first arg
+                # and returns a modified (i.e., filtered) `Query`.
+                filter_method = getattr(self.entity, 'filter_by_%s' % k, None)
+                if filter_method is not None:
+                    q = filter_method(q, v)
+                else:
+                    q = q.filter_by(**{k: v})
 
         if distinct:
             q = q.distinct()
